@@ -1,6 +1,6 @@
 package Git::ReleaseRepo::Command::checkout;
 {
-  $Git::ReleaseRepo::Command::checkout::VERSION = '0.005';
+  $Git::ReleaseRepo::Command::checkout::VERSION = '0.006';
 }
 # ABSTRACT: Checkout a release repository to work on it
 
@@ -38,20 +38,29 @@ augment execute => sub {
     my ( $self, $opt, $args ) = @_;
     my $repo = $self->git;
     my $branch;
+    if ( $repo->has_remote( 'origin' ) ) {
+        my $cmd = $repo->command( 'fetch', 'origin' );
+        my @stdout = readline $cmd->stdout;
+        my @stderr = readline $cmd->stderr;
+        $cmd->close;
+    }
+
     if ( $opt->bugfix ) {
-        $branch = $repo->latest_release_branch;
+        # We may not have pulled in a while, or ever.
+        if ( $repo->has_remote( 'origin' ) ) {
+            $branch = $repo->latest_release_branch( 'remotes/origin' );
+        }
+        else {
+            $branch = $repo->latest_release_branch;
+        }
     }
     else {
         $branch = $args->[0];
     }
     $repo->checkout( $branch );
+
     if ( $repo->has_remote( 'origin' ) ) {
         # Check if the repo needs updating
-        my $cmd = $repo->command( 'fetch', 'origin' );
-        my @stdout = readline $cmd->stdout;
-        my @stderr = readline $cmd->stderr;
-        $cmd->close;
-
         my %ref = $repo->show_ref;
         #; use Data::Dumper; print Dumper \%ref;
         my $ref_spec = 'refs/remotes/origin/' . $branch;
@@ -78,12 +87,22 @@ Git::ReleaseRepo::Command::checkout - Checkout a release repository to work on i
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Andrew Goudzwaard <adgoudz@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Doug Bell.
